Learn R Programming

robustbetareg (version 0.3.1)

HIC: Health Insurance Coverage

Description

A dataset containing the proportion of the population from several cities of the state of São Paulo, Brazil, in 2010.

Usage

data("HIC", package = "robustbetareg")

Arguments

Format

A data frame with 80 rows and 4 variables:

CITY

the corresponding city.

URB

proportion of the total population living in the city’s urban zone.

GDP

per capita gross domestic product.

HIC

the health insurance coverage index.

Details

This dataset was collected by the Institute of Applied Economic Research (Instituto de Pesquisa Econômica Aplicada, IPEA, Brazil). It includes information on 80 cities in the state of São Paulo, Brazil, in 2010.