Learn R Programming

robustbetareg (version 0.3.1)

methodsrobustbetareg: Methods for robustbetareg Objects

Description

Some S3 methods for objects of class "robustbetareg".

Usage

# S3 method for robustbetareg
summary(object, type = "sweighted2", ...)

# S3 method for robustbetareg coef(object, model = c("full", "mean", "precision"), ...)

# S3 method for summary.robustbetareg print(x, digits = max(3, getOption("digits") - 3), ...)

Value

methodsrobustbetareg returns different outputs for objects of class robustbetareg, depending on the used method.

Arguments

object, x

fitted model of class robustbetareg.

type

character specifying the type of residuals to be included in the summary output, see residuals.robustbetareg.

...

currently not used.

model

character specifying for which component of the model the coefficients should be extracted.

digits

the number of significant digits to use when printing.

Details

A set of methods for fitted model objects of class robustbetareg, including methods to the generic functions print and summary, which print the estimated coefficients along with some further information.

See Also

robustbetareg

Examples

Run this code
# \donttest{
data("HIC", package="robustbetareg")
fit=robustbetareg(HIC~URB+GDP|1,data=HIC,alpha=0.06)
summary(fit)
coef(fit)
# }

Run the code above in your browser using DataLab