Learn R Programming

robustbetareg (version 0.3.1)

plot.robustbetareg: Diagnostic Plots for robustbetareg Objects

Description

Several types of standard diagnostic plots can be produced interactively, involving different types of residuals.

Usage

# S3 method for robustbetareg
plot(x, ask = TRUE, ...)

Value

plot method for robustbetareg objects returns several diagnostic plots.

Arguments

x

fitted model object of class "robustbetareg".

ask

logical. If "TRUE" the user is asked before each plot.

...

graphical parameters passed to the plot function (see par).

See Also

robustbetareg, residuals.robustbetareg, plotenvelope

Examples

Run this code
# \donttest{
get(data("HIC", package = "robustbetareg"))
hic <- robustbetareg(HIC ~ URB + GDP | GDP,
                     data = HIC, alpha = 0.06)
# }

Run the code above in your browser using DataLab