Learn R Programming

robustbetareg (version 0.3.1)

set.link: Link functions for robust beta regression

Description

This function provides several link functions for robust beta regression.

Usage

set.link(link.mu = "logit", link.phi = "log")

Value

set.link provides the link function, inverse link function, first and second derivatives for both mean and precision submodels.

Arguments

link.mu

character specifying the mean link function. Currently, the functions "logit", "probit", "cauchit", "cloglog", and "loglog" are supported. Default is "logit".

link.phi

character specifying the precision link function. Currently, the functions "log", "identity", and "sqrt" are supported. Default is "log".

Examples

Run this code
# \donttest{
links = set.link(link.mu = "cauchit", link.phi = "sqrt")
attributes(links)# }

Run the code above in your browser using DataLab