methodsrobustbetareg returns different outputs for objects of
class robustbetareg, depending on the used method.
Arguments
object, x
fitted model of class robustbetareg.
type
character specifying the type of residuals to be included in the
summary output, see residuals.robustbetareg.
...
currently not used.
model
character specifying for which component of the model the
coefficients should be extracted.
digits
the number of significant digits to use when printing.
Details
A set of methods for fitted model objects of class robustbetareg,
including methods to the generic functions print and
summary, which print the estimated coefficients along with
some further information.