powered by
Several types of standard diagnostic plots can be produced interactively, involving different types of residuals.
# S3 method for robustbetareg plot(x, ask = TRUE, ...)
plot method for robustbetareg objects returns several diagnostic plots.
plot
robustbetareg
fitted model object of class "robustbetareg".
logical. If "TRUE" the user is asked before each plot.
TRUE
graphical parameters passed to the plot function (see par).
par
robustbetareg, residuals.robustbetareg, plotenvelope
residuals.robustbetareg
plotenvelope
# \donttest{ get(data("HIC", package = "robustbetareg")) hic <- robustbetareg(HIC ~ URB + GDP | GDP, data = HIC, alpha = 0.06) # }
Run the code above in your browser using DataLab